# -*- encoding: utf-8 -*-
##
##
## Copyright (C) 2011 Thibaut Girka <thib@sitedethib.com>
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published
## by the Free Software Foundation; version 3 only.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##

import struct

class Replay(object):
    def __init__(self, seed, seed2, score=0, survival_mode=False, keystates=None):
        self.seed = seed
        self.seed2 = seed2
        self.score = score
        self.survival_mode = survival_mode

        self.keystates = keystates or []


    def add_keystate(self, frame, keystate):
        old_keystate = 0 if not self.keystates else self.keystates[-1][1]
        if old_keystate != keystate:
            self.keystates.append((frame, keystate))


    def get_keystate(self, frame):
        keystate = 0
        for _frame, _keystate in self.keystates:
            if frame < _frame:
                break
            else:
                keystate = _keystate
        return keystate


    def save(self, file):
        file.write(struct.pack('<III?I', self.seed, self.seed2, self.score, self.survival_mode, len(self.keystates)))
        for frame, keystate in self.keystates:
            file.write(struct.pack('<IB', frame, keystate))


    @classmethod
    def load(cls, file):
        seed, seed2, score, survival_mode, nb_keystates = struct.unpack('<III?I', file.read(17))
        keystates = [struct.unpack('<IB', file.read(5)) for i in xrange(nb_keystates)]
        return cls(seed, seed2, score, survival_mode, keystates)

