# -*- encoding: utf-8 -*-
##
##
## Copyright (C) 2011 Thibaut Girka <thib@sitedethib.com>
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published
## by the Free Software Foundation; version 3 only.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##

import pyglet
from pyglet.gl import *

class MainWindow(pyglet.window.Window):
    def __init__(self, width, height):
        pyglet.window.Window.__init__(self, width, height, resizable=False,
                                      caption='Foreseen Yet Unpredictable Invader')
        self.keys = pyglet.window.key.KeyStateHandler()
        self.push_handlers(self.keys)
        self.screens = []


    def on_key_press(self, symbol, modifiers):
        if symbol == pyglet.window.key.S:
            glViewport(0, 0, self.width, self.height)
            pyglet.image.get_buffer_manager().get_color_buffer().save('screen.png')

        if self.screens:
            self.screens[-1].on_key_press(symbol, modifiers)


    def on_text(self, text):
        try:
            callback = self.screens[-1].on_text
        except (AttributeError, IndexError):
            pass
        else:
            callback(text)


    def on_text_motion(self, motion, select=False):
        try:
            callback = self.screens[-1].on_text_motion
        except (AttributeError, IndexError):
            pass
        else:
            callback(motion, select=False)


    def run(self):
        pyglet.clock.set_fps_limit(60)
        while self.screens and not self.has_exit:
            pyglet.clock.tick()
            self.dispatch_events()
            self.update()
            self.render()
            self.flip()


    def update(self):
        keystate = 0
        if self.keys[pyglet.window.key.UP]:
            keystate |= 1
        if self.keys[pyglet.window.key.DOWN]:
            keystate |= 2
        if self.keys[pyglet.window.key.LEFT]:
            keystate |= 4
        if self.keys[pyglet.window.key.RIGHT]:
            keystate |= 8
        if self.keys[pyglet.window.key.RIGHT]:
            keystate |= 8
        if self.keys[pyglet.window.key.LCTRL]:
            keystate |= 16
        if self.keys[pyglet.window.key.X]:
            keystate |= 32
        if self.keys[pyglet.window.key.LSHIFT]:
            keystate |= 64

        if self.screens:
            self.screens[-1].update(keystate)


    def render(self):
        if self.screens:
            self.screens[-1].render()

