# -*- encoding: utf-8 -*-
##
##
## Copyright (C) 2011 Thibaut Girka <thib@sitedethib.com>
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published
## by the Free Software Foundation; version 3 only.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##

import os
import random

import pyglet
from pyglet.gl import *

from fyui.game.levels import level_seeds
from fyui.game.game import Game
from fyui.screens.gamescreen import GameScreen


class CampaignScreen(object):
    def __init__(self, screen_list):
        self.screen_list = screen_list
        self.state = 0
        self.game = None


    def on_key_press(self, key, modifiers):
        pass


    def update(self, keystate):
        if self.game is not None and self.game.state != 1: #TODO
            self.screen_list.remove(self) #TODO
            return

        if self.state == 0:
            self.start_text_screen('intro.txt')
            self.state = 1
        elif self.state == 1:
            self.game = Game(400, 500, seed=level_seeds[0])
            self.screen_list.append(GameScreen(self.game, self.screen_list))
            self.state = 2
        elif self.state == 2:
            self.start_text_screen('level2.txt')
            self.state = 3
        elif self.state == 3:
            self.game = Game(400, 500, seed=level_seeds[1])
            self.screen_list.append(GameScreen(self.game, self.screen_list))
            self.state = 4
        elif self.state == 4:
            self.start_text_screen('level3.txt')
            self.state = 5
        elif self.state == 5:
            self.game = Game(400, 500, seed=level_seeds[2])
            self.screen_list.append(GameScreen(self.game, self.screen_list))
            self.state = 6
        elif self.state == 6:
            self.start_text_screen('level4.txt')
            self.state = 7
        elif self.state == 7:
            self.game = Game(400, 500, seed=level_seeds[3])
            self.screen_list.append(GameScreen(self.game, self.screen_list))
            self.state = 8
        elif self.state == 8:
            self.start_text_screen('end.txt')
            self.state = 9
        else:
            self.screen_list.remove(self)


    def render(self):
        pass


    def start_text_screen(self, name):
        with pyglet.resource.file(name, 'r') as file:
            text = file.read().decode('utf8')
        self.screen_list.append(TextScreen(self.screen_list, text))




class TextScreen(object):
    def __init__(self, screen_list, text):
        self.screen_list = screen_list
        self.label = pyglet.text.Label('', font_name='Mono', font_size=16, anchor_y='top', multiline=True, width=520, y=500)
        self.text = text
        self.delay = 5
        self.displayed_text = ''
        self.displayed_characters = 0
        self.ellapsed_frames = 0
        self.frame = 0


    def quit(self):
        self.screen_list.remove(self)


    def on_key_press(self, key, modifiers):
        if key == pyglet.window.key.ESCAPE:
            self.quit()


    def update(self, keystate):
        if self.frame % (1 if (keystate & 127) else self.delay) == 0:
            char = self.text[self.displayed_characters]
            self.displayed_characters += 1
            if char == u'⎚':
                self.displayed_text = ''
            elif char == u'♩':
                self.delay = 12
            elif char == u'♪':
                self.delay = 6
            elif char == u'♬':
                self.delay = 3
            else:
                self.ellapsed_frames = 0
                self.displayed_text += char
        self.label.text = self.displayed_text + ('_' if self.ellapsed_frames % 60 < 30 else '')
        self.ellapsed_frames += 1
        self.frame += 1
        if self.displayed_characters == len(self.text):
            self.quit()


    def render(self):
        glClearColor(0, 0, 0, 1)
        glClear(GL_COLOR_BUFFER_BIT)
        self.label.draw()

