# -*- encoding: utf-8 -*-
##
##
## Copyright (C) 2011 Thibaut Girka <thib@sitedethib.com>
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published
## by the Free Software Foundation; version 3 only.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##

import os
import time
import glob

from fyui.screens.common import MenuScreen, MenuItem
from fyui.game.replay import Replay

import pyglet


class SaveReplayScreen(MenuScreen):
    def __init__(self, screen_list, replay):
        MenuScreen.__init__(self, screen_list)
        self.replay = replay
        self.background = pyglet.resource.image('replay_screen.png')

        self.selected_button = 0

        common_params = {'bold': True, 'font_name': 'Sans',
                         'anchor_x': 'center', 'anchor_y': 'center'}
        self.file_name = os.path.join('replays', '%s.rpy' % time.strftime('%Y%m%d%H%M%S'))
        self.label = pyglet.text.Label('A replay will be saved in %s.' % self.file_name, font_size=12, x=260, y=300, **common_params)
        common_params['font_size'] = 30
        self.buttons = [MenuItem(self.save_replay, '[Save]', x=140, y=200, **common_params),
                        MenuItem(self.quit, '[Discard]', x=380, y=200, **common_params)]


    def save_replay(self):
        dirpath = os.path.join(pyglet.resource.get_script_home(), 'replays')
        if not os.path.exists(dirpath):
            os.mkdir(dirpath)
        path = os.path.join(pyglet.resource.get_script_home(), self.file_name)
        with open(path, 'wb') as file:
            self.replay.save(file)
        self.quit()



    def update(self, keystate):
        pass


    def render(self):
        self.background.blit(0, 0)
        self.label.draw()
        for i, button in enumerate(self.buttons):
            if self.selected_button == i:
                button.color = (255, 255, 0, 255)
            else:
                button.color = (255, 255, 255, 255)
            button.draw()

