# -*- encoding: utf-8 -*-
##
##
## Copyright (C) 2011 Thibaut Girka <thib@sitedethib.com>
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published
## by the Free Software Foundation; version 3 only.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##

import os

import json
import pyglet

from fyui.screens.common import MenuScreen, MenuItem
from fyui.game.levels import level_seeds
from fyui.game.game import Game
from fyui.screens.gamescreen import GameScreen


class SurvivalScreen(MenuScreen):
    def __init__(self, screen_list):
        MenuScreen.__init__(self, screen_list)
        self.background = pyglet.resource.image('survival_screen.png')
        common_params = {'color': (255, 255, 0, 255), 'bold': True, 'font_size': 18, 'anchor_y': 'top', 'y': 380}
        self.selected_button = 0

        self.header = [pyglet.text.Label('Level', x=40, anchor_x='left', **common_params),
                       pyglet.text.Label('High Score', x=480, anchor_x='right', **common_params)]

        common_params['bold'] = False
        y = common_params['y']
        del common_params['y']
        self.buttons = [MenuItem(lambda: self.start_game(0), 'Level 1', x=40, anchor_x='left', y=y-30, **common_params),
                        MenuItem(lambda: self.start_game(1), 'Level 2', x=40, anchor_x='left', y=y-60, **common_params),
                        MenuItem(lambda: self.start_game(2), 'Level 3', x=40, anchor_x='left', y=y-90, **common_params),
                        MenuItem(lambda: self.start_game(3), 'Level 4', x=40, anchor_x='left', y=y-120, **common_params)]
        self.score_labels = [pyglet.text.Label('%010d' % 0, x=480, anchor_x='right', y=y-30, **common_params),
                             pyglet.text.Label('%010d' % 0, x=480, anchor_x='right', y=y-60, **common_params),
                             pyglet.text.Label('%010d' % 0, x=480, anchor_x='right', y=y-90, **common_params),
                             pyglet.text.Label('%010d' % 0, x=480, anchor_x='right', y=y-120, **common_params)]

        self.update_scores()


    def start_game(self, index):
        game = Game(400, 500, seed=level_seeds[index], survival_mode=True)
        self.screen_list.remove(self)
        self.screen_list.append(GameScreen(game, self.screen_list))


    def update_scores(self):
        try:
            with open(os.path.join(pyglet.resource.get_script_home(), 'scores.dat'), 'r') as file:
                scores = json.load(file)
        except IOError:
            pass
        else:
            for label, seed in zip(self.score_labels, level_seeds):
                score = scores.get(str(seed), [(None, 0)])[0][-1]
                label.text = '%010d' % score


    def update(self, keystate):
        pass


    def render(self):
        self.background.blit(0, 0)
        for label in self.header:
            label.draw()
        for i, (button, score_label) in enumerate(zip(self.buttons, self.score_labels)):
            if self.selected_button == i:
                button.color = (255, 255, 0, 255)
                score_label.color = (255, 255, 0, 255)
            else:
                button.color = (255, 255, 255, 255)
                score_label.color = (255, 255, 255, 255)
            button.draw()
            score_label.draw()

